==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/filedesc/translations/filedesc_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>@default</name>
    <message>
        <source>FileDesc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Datei mit Beschreibung, die synchronisiert werden soll</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Pfad zur Datei, die Beschreibungen enthält, die mit diesem Modul gesetzt werden.</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Der zu setzende Zustand wird immer mit Bescheibtung sein</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Andere Beschreibungen erlauben</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always add description to status</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/filedesc/translations/filedesc_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>FileDesc</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Datei mit Beschreibung, die synchronisiert werden soll</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Pfad zur Datei, die Beschreibungen enthält, die mit diesem Modul gesetzt werden.</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Der zu setzende Zustand wird immer mit Bescheibtung sein</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Andere Beschreibungen erlauben</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Always add description to status</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
